@@ -27,6 +27,8 @@ import json
 import warnings
 from multiprocessing import Pool
 import tqdm
+from collections import Counter
+from functools import reduce
 
 log = logging.getLogger("my_logger")
 
@@ -84,46 +86,47 @@ def main():
         threads=args.threads,
         reference_lengths=args.reference_lengths,
         min_read_count=args.min_read_count,
+        min_read_ani=args.min_read_ani,
         scale=args.scale,
         sort_memory=args.sort_memory,
         plot=args.plot,
         plots_dir=out_files["coverage_plot_dir"],
         chunksize=args.chunk_size,
+        read_length_freqs=args.read_length_freqs,
     )
     logging.info("Reducing results to a single dataframe")
-    data = fast_flatten(list(filter(None, data)))
-    c_size = calc_chunksize(n_workers=args.threads, len_iterable=len(data), factor=4)
-    p = Pool(args.threads)
-    data_df = list(
-        tqdm.tqdm(
-            p.imap(get_summary, data, chunksize=c_size),
-            total=len(data),
-            leave=False,
-            ncols=80,
-            desc="References processed",
-        )
-    )
-    data_df = pd.DataFrame(data_df)
+    data = list(filter(None, data))
+    data_df = [x[0] for x in data]
+    # data_df = fast_flatten(list(filter(None, data_df)))
+    data_df = concat_df(data_df)
 
     if args.read_length_freqs:
-        logging.info("Calculating read length frequencies")
-        c_size = calc_chunksize(
-            n_workers=args.threads, len_iterable=len(data), factor=4
-        )
-        p = Pool(args.threads)
-        lens = list(
-            tqdm.tqdm(
-                p.imap(get_lens, data, chunksize=c_size),
-                total=len(data),
-                leave=False,
-                ncols=80,
-                desc="References processed",
-            )
-        )
+        logging.info("Calculating read length frequencies...")
+        lens = [x[1] for x in data]
         lens = json.dumps(lens, default=obj_dict, ensure_ascii=False, indent=4)
         with open(out_files["read_length_freqs"], "w", encoding="utf-8") as outfile:
             print(lens, file=outfile)
 
+    if args.read_hits_count:
+        logging.info("Calculating read hits counts...")
+        hits = [x[2] for x in data]
+
+        # merge dicts and sum values
+        hits = reduce(lambda x, y: x.update(y) or x, (Counter(dict(x)) for x in hits))
+        # hits = sum(map(Counter, hits), Counter())
+
+        # convert dict to dataframe
+        hits = (
+            pd.DataFrame.from_dict(hits, orient="index", columns=["count"])
+            .rename_axis("read")
+            .reset_index()
+            .sort_values(by="count", ascending=False)
+        )
+
+        hits.to_csv(
+            out_files["read_hits_count"], sep="\t", index=False, compression="gzip"
+        )
+
     logging.info(f"Writing reference statistics to {out_files['stats']}")
     data_df.to_csv(out_files["stats"], sep="\t", index=False, compression="gzip")
 
