@@ -11,7 +11,7 @@ import logging
 import warnings
 from bam_filter.utils import is_debug, calc_chunksize, initializer
 from bam_filter.entropy import entropy, norm_entropy, gini_coeff, norm_gini_coeff
-
+from collections import Counter, defaultdict
 import pyranges as pr
 
 # import cProfile as profile
@@ -99,6 +99,7 @@ def get_bam_stats(
     scale=1e6,
     plot=False,
     plots_dir="coverage-plots",
+    read_length_freqs=False,
 ):
     """
     Worker function per chromosome
@@ -110,7 +111,7 @@ def get_bam_stats(
     bam, references = params
     results = []
     samfile = pysam.AlignmentFile(bam, "rb")
-
+    read_hits = defaultdict(int)
     for reference in references:
         edit_distances = []
         # edit_distances_md = []
@@ -137,12 +138,14 @@ def get_bam_stats(
         ends = []
         strands = []
         cov_np = np.zeros(samfile.get_reference_length(reference), dtype=int)
+
         for aln in samfile.fetch(
             contig=reference, multiple_iterators=False, until_eof=False
         ):
             ani_read = (1 - ((aln.get_tag("NM") / aln.infer_query_length()))) * 100
             if ani_read >= min_read_ani:
                 n_alns += 1
+                read_hits[aln.query_name] += 1
                 if aln.has_tag("AS"):
                     read_aln_score.append(aln.get_tag("AS"))
                 else:
@@ -169,7 +172,7 @@ def get_bam_stats(
                 ends.append(aln.reference_end)
                 strands.append(strand)
 
-            cov_np[aln.reference_start : aln.reference_end] += 1
+                cov_np[aln.reference_start : aln.reference_end] += 1
 
         # get bases covered by reads pileup
 
@@ -333,13 +336,23 @@ def get_bam_stats(
         )
         results.append(data)
     samfile.close()
+    results = list(filter(None, results))
+    data_df = pd.DataFrame([x.to_summary() for x in results])
+    # read_hits = (
+    #     pd.DataFrame.from_dict(read_hits, orient="index", columns=["count"])
+    #     .rename_axis("read_id")
+    #     .reset_index()
+    # )
+    if read_length_freqs:
+        read_lens = [x.get_read_length_freqs for x in results]
+        return data_df, read_lens, read_hits
+    else:
+        return data_df, None, read_hits
     # prof.disable()
     # # print profiling output
     # stats = pstats.Stats(prof).strip_dirs().sort_stats("tottime")
     # stats.print_stats(5)  # top 10 rows
 
-    return results
-
 
 class BamAlignment:
     """
@@ -534,6 +547,7 @@ def process_bam(
     plot=False,
     plots_dir="coverage-plots",
     chunksize=None,
+    read_length_freqs=False,
 ):
     """
     Processing function: calls pool of worker functions
@@ -647,6 +661,7 @@ def process_bam(
                         scale=scale,
                         plot=plot,
                         plots_dir=plots_dir,
+                        read_length_freqs=read_length_freqs,
                     ),
                     params,
                 )
@@ -820,16 +835,16 @@ def filter_reference_BAM(
                 if max_chr_length > 536870912:
                     logging.info("A reference is longer than 2^29, indexing with csi")
                     pysam.index(
-                        out_files["bam_filtered"],
                         "-c",
                         "-@",
                         str(threads),
+                        out_files["bam_filtered"],
                     )
                 else:
                     pysam.index(
-                        out_files["bam_filtered"],
                         "-@",
                         str(threads),
+                        out_files["bam_filtered"],
                     )
 
             os.remove(out_files["bam_filtered_tmp"])
